using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Threading;
using System.Windows.Forms;

using BookShop.Controller;
using BookShop.Extensions;
using BookShop.Model;
using BookShop.View.Dialogs;

namespace BookShop.View
{
    /// <summary>
    /// A BookShop alkalmazs f ablaka.
    /// <para>
    /// A "partial" kulcssz azt jelzi, hogy az osztly kdja tbb fjlban is szerepel.
    /// </para>
    /// </summary>
    public partial class BookShopGui : Form
    {
        #region mezk
        private BookShopController m_controller;
        #endregion


        #region tulajdonsgok
        /// <summary>
        /// Visszaadja vagy belltja a <see cref="BookShopController"/> objektumot.
        /// </summary>
        public BookShopController Controller
        {
            get { return m_controller; }
            set { m_controller = value; }
        }
        #endregion


        #region konstruktor
        /// <summary>
        /// Ltrehozza a <see cref="BookShopController"/> osztly egy j pldnyt.
        /// </summary>
        public BookShopGui()
        {
            InitializeComponent();
        }
        #endregion


        #region esemnykezelk
        /// <summary>
        /// Az <see cref="exitToolStripMenuItem"/> menpont kivlasztsakor kilpnk
        /// az alkalmazsbl.
        /// </summary>
        /// <param name="sender">Az esemny kldje.</param>
        /// <param name="e">Az esemny argumentumai.</param>
        private void ExitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // Az alkalmazs bezrsa.
            Application.Exit();
        }
        #endregion

        #region segdfggvnyek
        public static void ShowMessage(String title, String message)
        {
            MessageBox.Show(
                message,
                title,
                MessageBoxButtons.OK,
                MessageBoxIcon.Error);
        }
        #endregion

        private void mutargyHozzaadasaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            UjMutargy ujMutargy = new UjMutargy(this);
            ujMutargy.ShowDialog();
        }

        private void mtrgyakListzsaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            IEnumerable<Mutargy> mutargyak = Controller.MutargyLista();
            mutargyDataGridView.DataSource = null;
            mutargyDataGridView.DataSource = mutargyak;
            mutargyDataGridView.Visible = true;
        }

        private void mtrgyKivlasztsaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            MutargyKivalasztas mutargyKivalasztas = new MutargyKivalasztas(this);
            mutargyKivalasztas.ShowDialog();
        }
    }
}
